@@ -18,6 +18,7 @@ from .partition import Partition
 from .paths import LocationPath, TopicPath, SubscriptionPath
 from .message_metadata import MessageMetadata
 from .flow_control_settings import FlowControlSettings, DISABLED_FLOW_CONTROL
+from .backlog_location import BacklogLocation, PublishTime, EventTime
 
 __all__ = (
     "CloudRegion",
@@ -28,4 +29,7 @@ __all__ = (
     "MessageMetadata",
     "SubscriptionPath",
     "TopicPath",
+    "BacklogLocation",
+    "PublishTime",
+    "EventTime",
 )
